#[non_exhaustive]pub enum PersistentReadiness {
Started,
OutputContains(String),
Command(ProcessSpec),
}Expand description
Persistent process readiness policy.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Started
The process is ready immediately after it is spawned.
OutputContains(String)
The process is ready when either output stream contains the text.
Command(ProcessSpec)
The process is ready when a command exits successfully.