pub fn persistent_start_error_kind(
error: &AppError,
) -> Option<PersistentStartErrorKind>Expand description
Return the structured persistent startup error kind attached to an AppError.
pub fn persistent_start_error_kind(
error: &AppError,
) -> Option<PersistentStartErrorKind>Return the structured persistent startup error kind attached to an AppError.