pub async fn run_with_cancel(
spec: &ProcessSpec,
config: &ProcessConfig,
cancel: CancellationToken,
) -> AppResult<ProcessResult>Expand description
Execute a subprocess with the given configuration and cancellation token.
pub async fn run_with_cancel(
spec: &ProcessSpec,
config: &ProcessConfig,
cancel: CancellationToken,
) -> AppResult<ProcessResult>Execute a subprocess with the given configuration and cancellation token.