PersistentConfig

Struct PersistentConfig 

pub struct PersistentConfig {
    pub readiness: PersistentReadiness,
    pub readiness_timeout: Duration,
    pub shutdown_grace_period: Duration,
    pub max_capture_bytes: Option<usize>,
    pub output: PersistentOutput,
    pub output_observer: Option<PersistentOutputObserver>,
}
Configuration for a persistent process.

Fields

readiness: PersistentReadiness

Readiness policy used before returning the running process.

readiness_timeout: Duration

Maximum time to wait for readiness.

shutdown_grace_period: Duration

Maximum time to wait after a graceful shutdown request before killing.

max_capture_bytes: Option<usize>

Maximum retained bytes for each captured output stream.

output: PersistentOutput

Output forwarding policy.

output_observer: Option<PersistentOutputObserver>

Optional byte observers for every persistent process output chunk read.

Implementations

Source

impl PersistentConfig

pub fn with_readiness(self, readiness: PersistentReadiness) -> Self

Set the readiness policy.

pub fn with_readiness_timeout(self, timeout: Duration) -> Self

Set the readiness timeout.

pub fn with_shutdown_grace_period(self, grace_period: Duration) -> Self

Set the shutdown grace period.

pub fn with_max_capture_bytes(self, bytes: usize) -> Self

Set the maximum retained bytes for each captured output stream.

pub fn with_unbounded_capture(self) -> Self

Disable capture bounds.

pub fn with_output(self, output: PersistentOutput) -> Self

Set the output forwarding policy.

pub fn with_output_observer(self, observer: PersistentOutputObserver) -> Self

Set byte observers for persistent output.