pub struct PersistentConfig {
pub readiness: PersistentReadiness,
pub readiness_timeout: Duration,
pub shutdown_grace_period: Duration,
pub max_capture_bytes: Option<usize>,
pub output: PersistentOutput,
}Expand description
Configuration for a persistent process.
Fields
readiness: PersistentReadinessReadiness policy used before returning the running process.
readiness_timeout: DurationMaximum time to wait for readiness.
shutdown_grace_period: DurationMaximum time to wait after a graceful shutdown request before killing.
max_capture_bytes: Option<usize>Maximum retained bytes for each captured output stream.
output: PersistentOutputOutput forwarding policy.
Implementations
Sourceimpl PersistentConfig
impl PersistentConfig
Sourcepub fn with_readiness(self, readiness: PersistentReadiness) -> Self
pub fn with_readiness(self, readiness: PersistentReadiness) -> Self
Set the readiness policy.
Sourcepub fn with_readiness_timeout(self, timeout: Duration) -> Self
pub fn with_readiness_timeout(self, timeout: Duration) -> Self
Set the readiness timeout.
Sourcepub fn with_shutdown_grace_period(self, grace_period: Duration) -> Self
pub fn with_shutdown_grace_period(self, grace_period: Duration) -> Self
Set the shutdown grace period.
Sourcepub fn with_max_capture_bytes(self, bytes: usize) -> Self
pub fn with_max_capture_bytes(self, bytes: usize) -> Self
Set the maximum retained bytes for each captured output stream.
Sourcepub fn with_unbounded_capture(self) -> Self
pub fn with_unbounded_capture(self) -> Self
Disable capture bounds.
Sourcepub fn with_output(self, output: PersistentOutput) -> Self
pub fn with_output(self, output: PersistentOutput) -> Self
Set the output forwarding policy.